@@ -1,24 +1,14 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  begin:     Wed Aug 04 2004
-  copyright: (C) 2002,2003,2004 by Dario Abatianni
-  email:     eisfuchs@tigress.com
-*/
-
-/* An instance of ChannelNick is made for each nick in each channel.
-   So for a person in multiple channels, they will have one NickInfo, and multiple ChannelNicks.
-   It contains a pointer to the NickInfo, and the mode of that person in the channel.
+    SPDX-FileCopyrightText: 2002, 2003, 2004 Dario Abatianni <eisfuchs@tigress.com>
 */
 
 #include "channelnick.h"
+
 #include "channel.h"
 #include "server.h"
+#include "konversation_log.h"
 
 
 ChannelNick::ChannelNick(const NickInfoPtr& nickInfo, const QString& channel)
@@ -93,14 +83,14 @@ bool ChannelNick::setMode(char mode, bool state)
         case 'v':
             return setVoice(state);
         default:
-            qDebug() << "Mode '" << mode << "' not recognised in setModeForChannelNick";
+            qCDebug(KONVERSATION_LOG) << "Mode '" << mode << "' not recognised in setModeForChannelNick";
             return false;
     }
 }
 
 /** Used still for passing modes from inputfilter to Server.  Should be removed.
  */
-bool ChannelNick::setMode(int mode)
+bool ChannelNick::setMode(uint mode)
 {
     bool voice = mode%2;
     mode >>= 1;
@@ -203,10 +193,10 @@ QString ChannelNick::tooltip() const
     //if(modes.empty()) modes << i18n("A normal user");
     if(!modes.empty())
     {
-        tooltip << "<tr><td><b>" << i18n("Mode") << ":</b></td><td>" << modes.join(QStringLiteral(", ")) << "</td></tr>";
+        tooltip << "<tr><td><b>" << i18n("Mode") << ":</b></td><td>" << modes.join(QLatin1String(", ")) << "</td></tr>";
     }
     tooltip << "</table></qt>";
-    //qDebug() << strTooltip ;
+    //qCDebug(KONVERSATION_LOG) << strTooltip ;
     //if(!dirty) return QString();
     return strTooltip;
 }
