@@ -1,13 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  copyright: (C) 2004 by Peter Simonsson
-  email:     psn@linux.se
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
 */
 
 #include "servergroupdialog.h"
@@ -25,8 +19,6 @@
 #include <QCheckBox>
 
 #include <KMessageBox>
-#include <QPushButton>
-#include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
 
@@ -44,7 +36,6 @@ namespace Konversation
         setLayout(mainLayout);
         mainLayout->addWidget(mainWidget);
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
-        okButton->setDefault(true);
         okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         connect(buttonBox, &QDialogButtonBox::accepted, this, &ServerGroupDialog::accept);
         connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerGroupDialog::reject);
@@ -60,25 +51,26 @@ namespace Konversation
 
         connect(m_mainWidget->m_editIdentityButton, &QPushButton::clicked, this, &ServerGroupDialog::editIdentity);
 
-        IdentityList identities = Preferences::identityList();
+        const IdentityList identities = Preferences::identityList();
 
-        for (IdentityList::ConstIterator it = identities.constBegin(); it != identities.constEnd(); ++it)
-            m_mainWidget->m_identityCBox->addItem((*it)->getName());
+        for (const auto& identity : identities) {
+            m_mainWidget->m_identityCBox->addItem(identity->getName());
+        }
 
-        m_mainWidget->m_removeServerButton->setIcon(QIcon::fromTheme("list-remove"));
-        m_mainWidget->m_upServerBtn->setIcon(QIcon::fromTheme("arrow-up"));
-        m_mainWidget->m_downServerBtn->setIcon(QIcon::fromTheme("arrow-down"));
+        m_mainWidget->m_removeServerButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
+        m_mainWidget->m_upServerBtn->setIcon(QIcon::fromTheme(QStringLiteral("arrow-up")));
+        m_mainWidget->m_downServerBtn->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
 
         connect(m_mainWidget->m_addServerButton, &QPushButton::clicked, this, &ServerGroupDialog::addServer);
-        connect(m_mainWidget->m_changeServerButton, SIGNAL(clicked()), this, SLOT(editServer()));
+        connect(m_mainWidget->m_changeServerButton, &QPushButton::clicked, this, QOverload<>::of(&ServerGroupDialog::editServer));
         connect(m_mainWidget->m_removeServerButton, &QToolButton::clicked, this, &ServerGroupDialog::deleteServer);
         connect(m_mainWidget->m_serverLBox, &QListWidget::itemSelectionChanged, this, &ServerGroupDialog::updateServerArrows);
         connect(m_mainWidget->m_upServerBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveServerUp);
         connect(m_mainWidget->m_downServerBtn, &QToolButton::clicked, this, &ServerGroupDialog::moveServerDown);
 
-        m_mainWidget->m_removeChannelButton->setIcon(QIcon::fromTheme("list-remove"));
-        m_mainWidget->m_upChannelBtn->setIcon(QIcon::fromTheme("arrow-up"));
-        m_mainWidget->m_downChannelBtn->setIcon(QIcon::fromTheme("arrow-down"));
+        m_mainWidget->m_removeChannelButton->setIcon(QIcon::fromTheme(QStringLiteral("list-remove")));
+        m_mainWidget->m_upChannelBtn->setIcon(QIcon::fromTheme(QStringLiteral("arrow-up")));
+        m_mainWidget->m_downChannelBtn->setIcon(QIcon::fromTheme(QStringLiteral("arrow-down")));
 
         connect(m_mainWidget->m_addChannelButton, &QPushButton::clicked, this, &ServerGroupDialog::addChannel);
         connect(m_mainWidget->m_changeChannelButton, &QPushButton::clicked, this, &ServerGroupDialog::editChannel);
@@ -118,20 +110,16 @@ namespace Konversation
         m_mainWidget->m_autoConnectCBox->setChecked(settings->autoConnectEnabled());
         m_serverList = settings->serverList();
         m_channelHistory = settings->channelHistory();
-        ServerList::iterator it;
         m_mainWidget->m_serverLBox->clear();
 
-        for(it = m_serverList.begin(); it != m_serverList.end(); ++it)
-        {
-            m_mainWidget->m_serverLBox->addItem((*it).host());
+        for (const auto& server : qAsConst(m_serverList)) {
+            m_mainWidget->m_serverLBox->addItem(server.host());
         }
 
         m_channelList = settings->channelList();
-        ChannelList::iterator it2;
 
-        for(it2 = m_channelList.begin(); it2 != m_channelList.end(); ++it2)
-        {
-            m_mainWidget->m_channelLBox->addItem((*it2).name());
+        for (const auto& channel : qAsConst(m_channelList)) {
+            m_mainWidget->m_channelLBox->addItem(channel.name());
         }
     }
 
@@ -153,7 +141,7 @@ namespace Konversation
         return settings;
     }
 
-    ServerSettings ServerGroupDialog::editedServer()
+    ServerSettings ServerGroupDialog::editedServer() const
     {
         if (m_editedServer && m_editedServerIndex < m_serverList.count())
         {
@@ -163,7 +151,7 @@ namespace Konversation
         return ServerSettings(QString());
     }
 
-    int ServerGroupDialog::execAndEditServer(ServerSettings server)
+    int ServerGroupDialog::execAndEditServer(const ServerSettings &server)
     {
         show();
         editServer(server);
@@ -203,7 +191,7 @@ namespace Konversation
         }
     }
 
-    void ServerGroupDialog::editServer(ServerSettings server)
+    void ServerGroupDialog::editServer(const ServerSettings &server)
     {
         // Track the server the Server List dialog told us to edit
         // and find out which server to select in the listbox
@@ -235,8 +223,8 @@ namespace Konversation
     {
         QList<QListWidgetItem*> serverBoxSelection = m_mainWidget->m_serverLBox->selectedItems();
 
-        if (m_mainWidget->m_serverLBox->count() && serverBoxSelection.count())
-        {
+        const bool hasServerSelected = !serverBoxSelection.isEmpty();
+        if (m_mainWidget->m_serverLBox->count() && hasServerSelected) {
             QListWidgetItem* selectedServer = serverBoxSelection.first();
             int selectedServerRow = m_mainWidget->m_serverLBox->row(selectedServer);
 
@@ -249,8 +237,8 @@ namespace Konversation
             m_mainWidget->m_downServerBtn->setEnabled(false);
         }
 
-        m_mainWidget->m_removeServerButton->setEnabled(serverBoxSelection.count());
-        m_mainWidget->m_changeServerButton->setEnabled(serverBoxSelection.count());
+        m_mainWidget->m_removeServerButton->setEnabled(hasServerSelected);
+        m_mainWidget->m_changeServerButton->setEnabled(hasServerSelected);
     }
 
     void ServerGroupDialog::moveServerUp()
@@ -342,8 +330,8 @@ namespace Konversation
     {
         QList<QListWidgetItem*> channelBoxSelection = m_mainWidget->m_channelLBox->selectedItems();
 
-        if (m_mainWidget->m_channelLBox->count() && channelBoxSelection.count())
-        {
+        const bool hasChannelSelected = !channelBoxSelection.isEmpty();
+        if (m_mainWidget->m_channelLBox->count() && hasChannelSelected) {
             QListWidgetItem* selectedChannel = channelBoxSelection.first();
             int selectedChannelRow = m_mainWidget->m_channelLBox->row(selectedChannel);
 
@@ -356,8 +344,8 @@ namespace Konversation
             m_mainWidget->m_downChannelBtn->setEnabled(false);
         }
 
-        m_mainWidget->m_removeChannelButton->setEnabled(channelBoxSelection.count());
-        m_mainWidget->m_changeChannelButton->setEnabled(channelBoxSelection.count());
+        m_mainWidget->m_removeChannelButton->setEnabled(hasChannelSelected);
+        m_mainWidget->m_changeChannelButton->setEnabled(hasChannelSelected);
     }
 
     void ServerGroupDialog::moveChannelUp()
@@ -399,12 +387,11 @@ namespace Konversation
 
         if(dlg->exec() == QDialog::Accepted)
         {
-            IdentityList identities = Preferences::identityList();
+            const IdentityList identities = Preferences::identityList();
             m_mainWidget->m_identityCBox->clear();
 
-            for(IdentityList::ConstIterator it = identities.constBegin(); it != identities.constEnd(); ++it)
-            {
-                m_mainWidget->m_identityCBox->addItem((*it)->getName());
+            for (const auto& identity : identities) {
+                m_mainWidget->m_identityCBox->addItem(identity->getName());
             }
 
             const int i = m_mainWidget->m_identityCBox->findText(dlg->currentIdentity()->getName());
@@ -430,7 +417,7 @@ namespace Konversation
         {
             KMessageBox::error(this, i18n("The network name is required."));
         }
-        else if (m_serverList.count() == 0)
+        else if (m_serverList.isEmpty())
         {
             KMessageBox::error(this, i18n("You need to add at least one server to the network."));
         }
@@ -451,7 +438,6 @@ namespace Konversation
         
         QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
         m_okButton = buttonBox->button(QDialogButtonBox::Ok);
-        m_okButton->setDefault(true);
         m_okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerDialog::reject);
         mainLayout->addWidget(buttonBox);
@@ -483,7 +469,7 @@ namespace Konversation
         m_mainWidget->m_proxyChBox->setChecked(!server.bypassProxy());
     }
 
-    ServerSettings ServerDialog::serverSettings()
+    ServerSettings ServerDialog::serverSettings() const
     {
         ServerSettings server;
         server.setHost(m_mainWidget->m_serverEdit->text());
@@ -517,7 +503,6 @@ namespace Konversation
         mainLayout->addWidget(mainWidget);
         QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
         m_okButton = buttonBox->button(QDialogButtonBox::Ok);
-        m_okButton->setDefault(true);
         m_okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
         connect(buttonBox, &QDialogButtonBox::rejected, this, &ChannelDialog::reject);
         mainLayout->addWidget(buttonBox);
@@ -546,7 +531,7 @@ namespace Konversation
         m_mainWidget->m_passwordEdit->setText(channel.password());
     }
 
-    ChannelSettings ChannelDialog::channelSettings()
+    ChannelSettings ChannelDialog::channelSettings() const
     {
         ChannelSettings channel;
         channel.setName(m_mainWidget->m_channelEdit->text());
