@@ -1,29 +1,22 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005-2007 Joris Guisson <joris.guisson@gmail.com>
-  Copyright (C) 2009 Michael Kreitzer <mrgrim@gr1m.org>
+    SPDX-FileCopyrightText: 2005-2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2009 Michael Kreitzer <mrgrim@gr1m.org>
 */
 
 #include "upnprouter.h"
+
 #include "upnpdescriptionparser.h"
 #include "soap.h"
+#include "konversation_log.h"
+
+#include <KLocalizedString>
+#include <KIO/StoredTransferJob>
 
 #include <QCoreApplication>
-#include <QNetworkReply>
 
-#include <KDebug>
-#include <KLocale>
-#include <KIO/Job>
-#include <KIO/NetAccess>
-#include <kio/jobclasses.h>
-
-#include <stdlib.h>
+#include <cstdlib>
 
 
 namespace Konversation
@@ -48,21 +41,21 @@ namespace Konversation
 
         void UPnPService::setProperty(const QString & name,const QString & value)
         {
-            if (name == "serviceType")
+            if (name == QLatin1String("serviceType"))
                 servicetype = value;
-            else if (name == "controlURL")
+            else if (name == QLatin1String("controlURL"))
                 controlurl = value;
-            else if (name == "eventSubURL")
+            else if (name == QLatin1String("eventSubURL"))
                 eventsuburl = value;
-            else if (name == "SCPDURL")
+            else if (name == QLatin1String("SCPDURL"))
                 scpdurl = value;
-            else if (name == "serviceId")
+            else if (name == QLatin1String("serviceId"))
                 serviceid = value;
         }
 
         void UPnPService::clear()
         {
-            servicetype = controlurl = eventsuburl = scpdurl = serviceid = "";
+            servicetype = controlurl = eventsuburl = scpdurl = serviceid = QString();
         }
 
         UPnPService & UPnPService::operator = (const UPnPService & s)
@@ -79,46 +72,42 @@ namespace Konversation
 
         void UPnPDeviceDescription::setProperty(const QString & name,const QString & value)
         {
-            if (name == "friendlyName")
+            if (name == QLatin1String("friendlyName"))
                 friendlyName = value;
-            else if (name == "manufacturer")
+            else if (name == QLatin1String("manufacturer"))
                 manufacturer = value;
-            else if (name == "modelDescription")
+            else if (name == QLatin1String("modelDescription"))
                 modelDescription = value;
-            else if (name == "modelName")
+            else if (name == QLatin1String("modelName"))
                 modelName = value;
-            else if (name == "modelNumber")
+            else if (name == QLatin1String("modelNumber"))
                 modelNumber = value;
         }
 
         ///////////////////////////////////////
 
-        UPnPRouter::UPnPRouter(const QString & server,const KUrl & location,const QString & uuid) : server(server),location(location),uuid(uuid)
+        UPnPRouter::UPnPRouter(const QString & server,const QUrl &location,const QString & uuid) : server(server),location(location),uuid(uuid)
         {
         }
 
 
         UPnPRouter::~UPnPRouter()
         {
-            QListIterator<Forwarding*> itr(forwards);
-            while (itr.hasNext())
-            {
-                Forwarding *check = itr.next();
+            for (Forwarding *check : qAsConst(forwards)) {
                 undoForward(check->port, check->proto);
             }
 
             // We need to give time for the QNetworkManager to process the undo forward commands. Continue
             // Processing the event loop from here until there are no more forwards.
-            while(forwards.size() > 0)
-            {
+            while (!forwards.isEmpty()) {
                 QCoreApplication::processEvents(QEventLoop::WaitForMoreEvents);
             }
         }
 
         void UPnPRouter::addService(const UPnPService & s)
         {
-            if (!( s.servicetype.contains("WANIPConnection") ||
-                   s.servicetype.contains("WANPPPConnection") ))
+            if (!( s.servicetype.contains(QLatin1String("WANIPConnection")) ||
+                   s.servicetype.contains(QLatin1String("WANPPPConnection")) ))
                 return;
 
             // Confirm this service is connected. Place in pending queue.
@@ -131,12 +120,12 @@ namespace Konversation
         {
             if (j->error())
             {
-                error = i18n("Failed to download %1: %2",location.prettyUrl(),j->errorString());
-                kDebug() << error << endl;
+                error = i18n("Failed to download %1: %2",location.url(),j->errorString());
+                qCDebug(KONVERSATION_LOG) << error;
                 return;
             }
 
-            KIO::StoredTransferJob* st = (KIO::StoredTransferJob*)j;
+            auto* st = static_cast<KIO::StoredTransferJob*>(j);
             // load in the file (target is always local)
             UPnPDescriptionParser desc_parse;
             bool ret = desc_parse.parse(st->data(),this);
@@ -152,66 +141,45 @@ namespace Konversation
         {
             error.clear();
             // downlaod XML description into a temporary file in /tmp
-            kDebug() << "Downloading XML file " << location << endl;
+            qCDebug(KONVERSATION_LOG) << "Downloading XML file " << location;
             KIO::Job* job = KIO::storedGet(location,KIO::NoReload, KIO::Overwrite | KIO::HideProgressInfo);
-            connect(job,SIGNAL(result(KJob*)),this,SLOT(downloadFinished(KJob*)));
+            connect(job, &KIO::Job::result, this, &UPnPRouter::downloadFinished);
         }
 
-        KJob *UPnPRouter::getStatusInfo(UPnPService s)
+        KJob *UPnPRouter::getStatusInfo(const UPnPService &s)
         {
-            kDebug() << "UPnP - Checking service status: " << s.servicetype << endl;
+            qCDebug(KONVERSATION_LOG) << "UPnP - Checking service status: " << s.servicetype;
 
-            QString action = "GetStatusInfo";
+            QString action = QStringLiteral("GetStatusInfo");
             QString comm = SOAP::createCommand(action,s.servicetype);
 
-            return sendSoapQuery(comm,s.servicetype + '#' + action,s.controlurl);
+            return sendSoapQuery(comm,s.servicetype + QLatin1Char('#') + action,s.controlurl);
         }
 
         bool UPnPRouter::forward(const QHostAddress & host, quint16 port, QAbstractSocket::SocketType proto)
         {
-            kDebug() << "Forwarding port " << host.toString() << port << " (" << (proto == QAbstractSocket::TcpSocket ? "TCP" : "UDP") << ")" << endl;
+            qCDebug(KONVERSATION_LOG) << "Forwarding port " << host.toString() << port << " (" << (proto == QAbstractSocket::TcpSocket ? "TCP" : "UDP") << ")";
 
             if (service.ready)
             {
                 // add all the arguments for the command
-                QList<SOAP::Arg> args;
-                SOAP::Arg a;
-                a.element = "NewRemoteHost";
-                args.append(a);
+                const QList<SOAP::Arg> args = {
+                    { QStringLiteral("NewRemoteHost"),             QString() },
+                    // the external port
+                    { QStringLiteral("NewExternalPort"),           QString::number(port) },
+                    // the protocol
+                    { QStringLiteral("NewProtocol"),
+                      (proto == QAbstractSocket::TcpSocket) ? QStringLiteral("TCP") : QStringLiteral("UDP") },
+                    // the local port
+                    { QStringLiteral("NewInternalPort"),           QString::number(port) },
+                    // the local IP address
+                    { QStringLiteral("NewInternalClient"),         host.toString() },
+                    { QStringLiteral("NewEnabled"),                QStringLiteral("1") },
+                    { QStringLiteral("NewPortMappingDescription"), QStringLiteral("Konversation UPNP") },
+                    { QStringLiteral("NewLeaseDuration"),          QStringLiteral("0") },
+                };
 
-                // the external port
-                a.element = "NewExternalPort";
-                a.value = QString::number(port);
-                args.append(a);
-
-                // the protocol
-                a.element = "NewProtocol";
-                a.value = proto == QAbstractSocket::TcpSocket ? "TCP" : "UDP";
-                args.append(a);
-
-                // the local port
-                a.element = "NewInternalPort";
-                a.value = QString::number(port);
-                args.append(a);
-
-                // the local IP address
-                a.element = "NewInternalClient";
-                a.value = host.toString();
-                args.append(a);
-
-                a.element = "NewEnabled";
-                a.value = '1';
-                args.append(a);
-
-                a.element = "NewPortMappingDescription";
-                a.value = QString("Konversation UPNP");
-                args.append(a);
-
-                a.element = "NewLeaseDuration";
-                a.value = '0';
-                args.append(a);
-
-                QString action = "AddPortMapping";
+                QString action = QStringLiteral("AddPortMapping");
                 QString comm = SOAP::createCommand(action,service.servicetype,args);
 
                 Forwarding *forward = new Forwarding;
@@ -220,19 +188,20 @@ namespace Konversation
                 forward->host = host;
                 forward->proto = proto;
 
-                if (KJob *req = sendSoapQuery(comm,service.servicetype + '#' + action,service.controlurl))
+                if (KJob *req = sendSoapQuery(comm,service.servicetype + QLatin1Char('#') + action,service.controlurl))
                 {
                     // erase old forwarding if one exists
                     // The UPnP spec states if an IGD receives a forward request that matches an existing request that it must accept it.
-                    QListIterator<Forwarding*> itr(forwards);
-                    while (itr.hasNext())
-                    {
-                        Forwarding *check = itr.next();
+                    auto it = forwards.begin();
+                    while (it != forwards.end()) {
+                        Forwarding *check = *it;
 
                         if (check->port == forward->port && check->host == forward->host && check->proto == forward->proto)
                         {
-                            forwards.removeAll(check);
+                            it = forwards.erase(it);
                             delete check;
+                        } else {
+                            ++it;
                         }
                     }
 
@@ -242,65 +211,55 @@ namespace Konversation
                     return true;
                 }
 
-                kDebug() << "Forwarding Failed: Failed to send SOAP query.";
+                qCDebug(KONVERSATION_LOG) << "Forwarding Failed: Failed to send SOAP query.";
                 delete forward;
             }
 
-            kDebug() << "Forwarding Failed: No UPnP Service.";
+            qCDebug(KONVERSATION_LOG) << "Forwarding Failed: No UPnP Service.";
             return false;
         }
 
         bool UPnPRouter::undoForward(quint16 port, QAbstractSocket::SocketType proto)
         {
-            kDebug() << "Undoing forward of port " << port
-                    << " (" << (proto == QAbstractSocket::TcpSocket ? "TCP" : "UDP") << ")" << endl;
+            qCDebug(KONVERSATION_LOG) << "Undoing forward of port " << port
+                    << " (" << (proto == QAbstractSocket::TcpSocket ? "TCP" : "UDP") << ")";
 
             if (service.ready)
             {
-                Forwarding *forward = NULL;
-
-                QListIterator<Forwarding*> itr(forwards);
-                while (itr.hasNext())
-                {
-                    Forwarding *check = itr.next();
+                Forwarding *forward = nullptr;
 
+                for (Forwarding *check : qAsConst(forwards)) {
                     if (check->port == port && check->proto == proto)
                         forward = check;
                 }
 
-                if (forward == NULL || pending_forwards.keys(forward).size() > 0)
+                if (forward == nullptr || !pending_forwards.keys(forward).isEmpty())
                     return false; // Either forward not found or forward is still pending
 
                 // add all the arguments for the command
-                QList<SOAP::Arg> args;
-                SOAP::Arg a;
-                a.element = "NewRemoteHost";
-                args.append(a);
+                const QList<SOAP::Arg> args = {
+                    { QStringLiteral("NewRemoteHost"),   QString() },
+                    // the external port
+                    { QStringLiteral("NewExternalPort"), QString::number(forward->port) },
+                    // the protocol
+                    { QStringLiteral("NewProtocol"),
+                      (forward->proto == QAbstractSocket::TcpSocket) ? QStringLiteral("TCP") : QStringLiteral("UDP") },
+                };
 
-                // the external port
-                a.element = "NewExternalPort";
-                a.value = QString::number(forward->port);
-                args.append(a);
-
-                // the protocol
-                a.element = "NewProtocol";
-                a.value = forward->proto == QAbstractSocket::TcpSocket ? "TCP" : "UDP";
-                args.append(a);
-
-                QString action = "DeletePortMapping";
+                QString action = QStringLiteral("DeletePortMapping");
                 QString comm = SOAP::createCommand(action,service.servicetype,args);
 
-                if (KJob *req = sendSoapQuery(comm,service.servicetype + '#' + action,service.controlurl))
+                if (KJob *req = sendSoapQuery(comm,service.servicetype + QLatin1Char('#') + action,service.controlurl))
                 {
                     pending_unforwards[req] = forward;
 
                     return true;
                 }
-                
-                kDebug() << "Undo forwarding Failed: Failed to send SOAP query.";
+
+                qCDebug(KONVERSATION_LOG) << "Undo forwarding Failed: Failed to send SOAP query.";
             }
 
-            kDebug() << "Undo forwarding Failed: No UPnP Service.";
+            qCDebug(KONVERSATION_LOG) << "Undo forwarding Failed: No UPnP Service.";
             return false;
         }
 
@@ -311,27 +270,27 @@ namespace Konversation
             if (location.port()<=0)
                 location.setPort(80);
 
-            KUrl address;
+            QUrl address;
 
-            address.setProtocol(QString("http"));
+            address.setScheme(QStringLiteral("http"));
             address.setHost(location.host());
             address.setPort(location.port());
             address.setPath(controlurl);
 
-            KIO::TransferJob *req = KIO::http_post( address, query.toAscii(), KIO::HideProgressInfo );
-            
-            req->addMetaData("content-type", QString("text/xml"));
-            req->addMetaData("UserAgent", QString("Konversation UPnP"));
-            req->addMetaData("customHTTPHeader", QString("SOAPAction: ") + soapact);
+            KIO::TransferJob *req = KIO::http_post( address, query.toLatin1(), KIO::HideProgressInfo );
+
+            req->addMetaData(QStringLiteral("content-type"), QStringLiteral("text/xml"));
+            req->addMetaData(QStringLiteral("UserAgent"), QStringLiteral("Konversation UPnP"));
+            req->addMetaData(QStringLiteral("customHTTPHeader"), QStringLiteral("SOAPAction: ") + soapact);
 
             soap_data_out[req] = QByteArray();
             soap_data_in[req]  = QByteArray();
-            
-            connect( req, SIGNAL(data(KIO::Job*,QByteArray)), this, SLOT(recvSoapData(KIO::Job*,QByteArray)) );
-            connect( req, SIGNAL(dataReq(KIO::Job*,QByteArray&)), this, SLOT(sendSoapData(KIO::Job*,QByteArray&)) );
-            
-            connect( req, SIGNAL(result(KJob*)), this, SLOT(onRequestFinished(KJob*)) );
-            
+
+            connect(req, &KIO::TransferJob::data, this, &UPnPRouter::recvSoapData);
+            connect(req, &KIO::TransferJob::dataReq, this, &UPnPRouter::sendSoapData);
+
+            connect(req, &KIO::TransferJob::result, this, &UPnPRouter::onRequestFinished);
+
             return req;
         }
 
@@ -350,8 +309,8 @@ namespace Konversation
         {
             if (r->error())
             {
-                kDebug() << "UPnPRouter : Error: " << r->errorString() << endl;
-                
+                qCDebug(KONVERSATION_LOG) << "UPnPRouter : Error: " << r->errorString();
+
                 if (pending_services.contains(r))
                 {
                     pending_services.remove(r);
@@ -359,53 +318,53 @@ namespace Konversation
                 else if (pending_forwards.contains(r))
                 {
                     emit forwardComplete(true, pending_forwards[r]->port);
-                    
+
                     forwards.removeAll(pending_forwards[r]);
                     pending_forwards.remove(r);
                 }
                 else if (pending_unforwards.contains(r))
                 {
                     emit unforwardComplete(true, pending_unforwards[r]->port);
-                    
+
                     forwards.removeAll(pending_unforwards[r]);
                     pending_unforwards.remove(r);
                 }
             }
             else
             {
-                QString reply(soap_data_in[r]);
+                const QString reply = QString::fromUtf8(soap_data_in[r]);
                 soap_data_in[r].clear();
 
-                kDebug() << "UPnPRouter : OK:" << endl;
-                
+                qCDebug(KONVERSATION_LOG) << "UPnPRouter : OK:";
+
                 if (pending_services.contains(r))
                 {
-                    if (reply.contains("Connected"))
+                    if (reply.contains(QLatin1String("Connected")))
                     {
                         // Lets just deal with one connected service for now. Last one wins.
                         service = pending_services[r];
                         service.ready = true;
-                        
-                        kDebug() << "Found connected service: " << service.servicetype << endl;
+
+                        qCDebug(KONVERSATION_LOG) << "Found connected service: " << service.servicetype;
                     }
-                    
+
                     pending_services.remove(r);
                 }
                 else if (pending_forwards.contains(r))
                 {
                     emit forwardComplete(false, pending_forwards[r]->port);
-                    
+
                     pending_forwards.remove(r);
                 }
                 else if (pending_unforwards.contains(r))
                 {
                     emit unforwardComplete(false, pending_unforwards[r]->port);
-                    
+
                     forwards.removeAll(pending_unforwards[r]);
                     pending_unforwards.remove(r);
                 }
             }
-            
+
             soap_data_in.remove(r);
             soap_data_out.remove(r);
         }
