@@ -1,16 +1,12 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2002 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2002 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #include "chatwindow.h"
+
 #include "channel.h"
 #include "query.h"
 #include "ircview.h"
@@ -19,28 +15,29 @@
 #include "application.h"
 #include "logfilereader.h"
 #include "viewcontainer.h"
+#include "konversation_log.h"
+
+#include <KUser>
 
 #include <QDateTime>
 #include <QDir>
 #include <QTextCodec>
 #include <QKeyEvent>
 #include <QScrollBar>
-
-#include <KUser>
 #include <QLocale>
 
 
 ChatWindow::ChatWindow(QWidget* parent) : QWidget(parent)
 {
     QVBoxLayout* mainLayout = new QVBoxLayout(this);
-    mainLayout->setMargin(margin());
+    mainLayout->setContentsMargins(margin(), margin(), margin(), margin());
     mainLayout->setSpacing(spacing());
 
-    setName("ChatWindowObject");
-    setTextView(0);
-    setInputBar(0);
+    setName(QStringLiteral("ChatWindowObject"));
+    setTextView(nullptr);
+    setInputBar(nullptr);
     firstLog = true;
-    m_server = 0;
+    m_server = nullptr;
     m_recreationScheduled = false;
     m_isTopLevelView = true;
     m_notificationsEnabled = true;
@@ -66,7 +63,7 @@ ChatWindow::~ChatWindow()
     }
 
     emit closing(this);
-    m_server=0;
+    m_server=nullptr;
 }
 
 void ChatWindow::childEvent(QChildEvent* event)
@@ -127,9 +124,8 @@ QString ChatWindow::getTitle() const
     QString title;
     if (getType() == Channel)
     {
-       title = QString("%1 (%2)")
-             .arg(getName())
-             .arg(getServer()->getDisplayName());
+       title = QStringLiteral("%1 (%2)")
+             .arg(getName(), getServer()->getDisplayName());
     }
     else
     {
@@ -148,15 +144,15 @@ QString ChatWindow::getURI(bool passNetwork)
     QString channel;
 
     if (getServer()->getUseSSL())
-        protocol = "ircs://";
+        protocol = QStringLiteral("ircs://");
     else
-        protocol = "irc://";
+        protocol = QStringLiteral("irc://");
 
     if (getType() == Channel)
     {
-        channel = getName().replace(QRegExp("^#"), QString());
+        channel = getName().remove(QRegExp(QStringLiteral("^#")));
         // must protect second #, but might as well protect all of them
-        channel.replace("#", "%23");
+        channel.replace(QLatin1String("#"), QLatin1String("%23"));
     }
 
     if (passNetwork)
@@ -177,13 +173,13 @@ QString ChatWindow::getURI(bool passNetwork)
     if (!passNetwork)
     {
         server = getServer()->getServerName();
-        port = ':'+QString::number(getServer()->getPort());
+        port = QLatin1Char(':') + QString::number(getServer()->getPort());
     }
 
-    if (server.contains(':')) // IPv6
-        server = '['+server+']';
+    if (server.contains(QLatin1Char(':'))) // IPv6
+        server = QLatin1Char('[') + server + QLatin1Char(']');
 
-    url = protocol+server+port+'/'+channel;
+    url = protocol + server + port + QLatin1Char('/') + channel;
 
     return url;
 }
@@ -207,7 +203,7 @@ void ChatWindow::setServer(Server* newServer)
 {
     if (!newServer)
     {
-        qDebug() << "ChatWindow::setServer(0)!";
+        qCDebug(KONVERSATION_LOG) << "ChatWindow::setServer(0)!";
     }
     else
     {
@@ -218,7 +214,7 @@ void ChatWindow::setServer(Server* newServer)
         if(getType() != ChannelList)
         {
             if(textView) textView->setServer(newServer);
-            else qDebug() << "textView==0!";
+            else qCDebug(KONVERSATION_LOG) << "textView==0!";
         }
 
         serverOnline(m_server->isConnected());
@@ -358,7 +354,7 @@ void ChatWindow::cdIntoLogPath()
     }
 
     // Add the logfile name to the path.
-    logfile.setFileName(logDir.path() + '/' + logName);
+    logfile.setFileName(logDir.path() + QLatin1Char('/') + logName);
 }
 
 void ChatWindow::setLogfileName(const QString& name)
@@ -372,12 +368,12 @@ void ChatWindow::setLogfileName(const QString& name)
         // status panels get special treatment here, since they have no server at the beginning
         if (getType() == Status || getType() == DccChat)
         {
-            logName = name + ".log";
+            logName = name + QLatin1String(".log");
         }
         else if (m_server)
         {
             // make sure that no path delimiters are in the name
-            logName = QString(m_server->getDisplayName().toLower()).append('_').append(name).append(".log").replace('/','_');
+            logName = QString(m_server->getDisplayName().toLower() + QLatin1Char('_') + name + QLatin1String(".log")).replace(QLatin1Char('/'), QLatin1Char('_'));
         }
 
         // load backlog to show
@@ -391,7 +387,6 @@ void ChatWindow::setLogfileName(const QString& name)
             {
                 qint64 filePosition;
 
-                QString backlogLine;
                 QTextStream backlog(&logfile);
                 backlog.setCodec(QTextCodec::codecForName("UTF-8"));
                 backlog.setAutoDetectUnicode(true);
@@ -436,7 +431,7 @@ void ChatWindow::setLogfileName(const QString& name)
                     // Loop until end of file reached
                     while(!backlog.atEnd() && filePosition < lastPacketHeadPosition)
                     {
-                        backlogLine = backlog.readLine();
+                        const QString backlogFileLine = backlog.readLine();
 
                         // check for deadlocks
                         if(backlog.pos() == filePosition)
@@ -445,12 +440,12 @@ void ChatWindow::setLogfileName(const QString& name)
                         }
 
                         // if a tab character is present in the line, meaning it is a valid chatline
-                        if (backlogLine.contains('\t'))
-                        {
+                        const int tabIndex = backlogFileLine.indexOf(QLatin1Char('\t'));
+                        if (tabIndex != -1) {
                             // extract first column from log
-                            QString backlogFirst = backlogLine.left(backlogLine.indexOf('\t'));
+                            const QString backlogFirst = backlogFileLine.left(tabIndex);
                             // cut first column from line
-                            backlogLine = backlogLine.mid(backlogLine.indexOf('\t') + 1);
+                            const QString backlogLine = backlogFileLine.mid(tabIndex + 1);
                             // Logfile is in utf8 so we don't need to do encoding stuff here
                             // append backlog with time and first column to text view
                             firstColumnsInPacket << backlogFirst;
@@ -468,7 +463,7 @@ void ChatWindow::setLogfileName(const QString& name)
                     firstColumns = firstColumnsInPacket + firstColumns;
                     messages = messagesInPacket + messages;
                 }
-                backlog.setDevice(0);
+                backlog.setDevice(nullptr);
                 logfile.close();
 
                 // trim
@@ -515,17 +510,16 @@ void ChatWindow::logText(const QString& text)
             }
 
             QDateTime dateTime = QDateTime::currentDateTime();
-            QString logLine(QString("[%1] [%2] %3\n").arg(QLocale().toString(dateTime.date(), QLocale::LongFormat)).
-                arg(QLocale().toString(dateTime.time(), QLocale::LongFormat)).arg(text));
+            QString logLine = QStringLiteral("[%1] [%2] %3\n").arg(QLocale().toString(dateTime.date(), QLocale::LongFormat), QLocale().toString(dateTime.time(), QLocale::LongFormat), text);
             logStream << logLine;
 
             // detach stream from file
-            logStream.setDevice(0);
+            logStream.setDevice(nullptr);
 
             // close file
             logfile.close();
         }
-        else qWarning() << "open(QIODevice::Append) for " << logfile.fileName() << " failed!";
+        else qCWarning(KONVERSATION_LOG) << "open(QIODevice::Append) for " << logfile.fileName() << " failed!";
     }
 }
 
@@ -561,13 +555,13 @@ IRCView* ChatWindow::getTextView() const
   return textView;
 }
 
-bool ChatWindow::log()
+bool ChatWindow::log() const
 {
   return Preferences::self()->log();
 }
 
 // reimplement this in all panels that have user input
-QString ChatWindow::getTextInLine()
+QString ChatWindow::getTextInLine() const
 {
     if (m_inputBar)
         return m_inputBar->toPlainText();
@@ -575,12 +569,12 @@ QString ChatWindow::getTextInLine()
         return QString();
 }
 
-bool ChatWindow::canBeFrontView()
+bool ChatWindow::canBeFrontView() const
 {
   return false;
 }
 
-bool ChatWindow::searchView()
+bool ChatWindow::searchView() const
 {
   return false;
 }
@@ -609,7 +603,7 @@ bool ChatWindow::eventFilter(QObject* watched, QEvent* e)
 {
     if(e->type() == QEvent::KeyPress)
     {
-        QKeyEvent* ke = static_cast<QKeyEvent*>(e);
+        auto* ke = static_cast<QKeyEvent*>(e);
 
         bool scrollMod = (Preferences::self()->useMultiRowInputBox() ? false : (ke->modifiers() == Qt::ShiftModifier));
 
@@ -711,12 +705,12 @@ void ChatWindow::msgHelper(const QString& recipient, const QString& message)
     QString result = message;
     QString visualization;
 
-    if (result.startsWith(Preferences::self()->commandChar() + "me"))
+    if (result.startsWith(Preferences::self()->commandChar() + QLatin1String("me")))
     {
         isAction = true;
 
-        result = result.mid(4);
-        visualization = QString("* %1 %2").arg(m_server->getNickname()).arg(result);
+        result.remove(0, 4);
+        visualization = QStringLiteral("* %1 %2").arg(m_server->getNickname(), result);
     }
     else
         visualization = result;
@@ -749,4 +743,14 @@ void ChatWindow::msgHelper(const QString& recipient, const QString& message)
     }
 }
 
+void ChatWindow::activateView()
+{
+    for(QWidget* widget = this; widget; widget = widget->parentWidget()) {
+        if (widget->window()) {
+            widget->show();
+            widget->activateWindow();
+            widget->raise();
+        }
+    }
+}
 
