@@ -1,17 +1,8 @@
-// Copyright 2009 Peter Simonsson <peter.simonsson@gmail.com>
-//
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License as
-// published by the Free Software Foundation; either version 2 of
-// the License, or (at your option) any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program.  If not, see <http://www.gnu.org/licenses/>.
+/*
+    SPDX-FileCopyrightText: 2009 Peter Simonsson <peter.simonsson@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pasteeditor.h"
 #include "preferences.h"
@@ -27,7 +18,7 @@
 #include <QAction>
 
 PasteEditor::PasteEditor(QWidget* parent)
-    : QDialog(parent), Ui::PasteEditor(), m_autoReplaceActionWasEnabled(true), m_autoReplaceAction(0)
+    : QDialog(parent), Ui::PasteEditor(), m_autoReplaceActionWasEnabled(true), m_autoReplaceAction(nullptr)
 {
     setWindowTitle(i18n("Edit Multiline Paste"));
     setModal(true);
@@ -44,7 +35,7 @@ PasteEditor::PasteEditor(QWidget* parent)
     m_textEditor->setFocus();
 
     // Get auto_replace action, check enabled state and make the connection
-    m_autoReplaceAction = Application::instance()->getMainWindow()->actionCollection()->action("auto_replace");
+    m_autoReplaceAction = Application::instance()->getMainWindow()->actionCollection()->action(QStringLiteral("auto_replace"));
     if (m_autoReplaceAction)
     {
         // Store action's original enabled state in ViewContainer
@@ -75,11 +66,11 @@ void PasteEditor::addQuotationIndicators()
 {
     QTextCursor cursor(m_textEditor->document());
     cursor.beginEditBlock();
-    cursor.insertText("> ");
+    cursor.insertText(QStringLiteral("> "));
 
     while(cursor.movePosition(QTextCursor::NextBlock, QTextCursor::MoveAnchor))
     {
-        cursor.insertText("> ");
+        cursor.insertText(QStringLiteral("> "));
     }
 
     cursor.endEditBlock();
@@ -88,22 +79,21 @@ void PasteEditor::addQuotationIndicators()
 void PasteEditor::removeNewlines()
 {
     QString text(m_textEditor->toPlainText());
-    text.remove('\r');
-    text.remove(QRegExp("^\n+|\n+$"));
+    text.remove(QLatin1Char('\r'));
+    text.remove(QRegExp(QStringLiteral("^\n+|\n+$")));
 
     int i = 0;
 
     while (i < text.length())
     {
-        if (text[i] == '\n')
-        {
+        if (text[i] == QLatin1Char('\n')) {
             if (text[i - 1].category() == QChar::Separator_Space)
             {
                 text.remove(i, 1);
                 continue;
             }
             else
-                text[i] = ' ';
+                text[i] = QLatin1Char(' ');
         }
 
         ++i;
