@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2004, 2009 Peter Simonsson <peter.simonsson@gmail.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2004, 2009 Peter Simonsson <peter.simonsson@gmail.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #ifndef KONVERSATIONTOPICLABEL_H
@@ -27,8 +22,8 @@ namespace Konversation
         Q_OBJECT
 
         public:
-            explicit TopicLabel(QWidget *parent = 0, const char *name = 0);
-            ~TopicLabel() override;
+            explicit TopicLabel(QWidget *parent = nullptr);
+            ~TopicLabel();
 
             QSize minimumSizeHint() const override;
             QSize sizeHint() const override;
@@ -46,9 +41,6 @@ namespace Konversation
             void clearStatusBarTempText();
 
         protected:
-            void updateSqueezedText();
-            QString rPixelSqueeze(const QString& text, int maxPixels);
-            int textWidth(const QString& text);
             void leaveEvent (QEvent*) override;
             void contextMenuEvent(QContextMenuEvent* ev) override;
             void resizeEvent(QResizeEvent*) override;
@@ -56,14 +48,19 @@ namespace Konversation
             void mousePressEvent(QMouseEvent* ev) override;
             void mouseMoveEvent(QMouseEvent* ev) override;
 
-        protected Q_SLOTS:
+        private Q_SLOTS:
             void highlightedSlot(const QString&);
 
         private:
+            QString rPixelSqueeze(const QString& text, int maxPixels) const;
+            int textWidth(const QString& text) const;
+
+            void updateSqueezedText();
             void resetLinkHighlightState();
 
             inline QString tagUrls(const QString& text, const QString& sender);
 
+        private:
             Server* m_server;
             QString m_channelName;
 
@@ -77,7 +74,9 @@ namespace Konversation
             QString m_dragUrl;
             bool m_mousePressedOnUrl;
             QPoint m_mousePressPosition;
-    };
 
+            Q_DISABLE_COPY(TopicLabel)
+    };
 }
+
 #endif
